package Amon2::Auth;
use strict;
use warnings;
use 5.008001;
our $VERSION = '0.02';

1;
__END__

=encoding utf8

=head1 NAME

Amon2::Auth - Authentication module for Amon2

=head1 DESCRIPTION

Amon2::Auth is authentication modules for Amon2.

Please read L<Amon2::Plugin::Web::Auth> for more details.

=head1 AUTHOR

Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF GMAIL COME<gt>

=head1 SEE ALSO

=head1 LICENSE

Copyright (C) Tokuhiro Matsuno

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
